"""所有的导入均使用真实映射."""
from classicML.api.models.base_model import BaseModel

from classicML.api.models.bayes.naive_bayes_classifier import NaiveBayesClassifier
from classicML.api.models.bayes.naive_bayes_classifier import NaiveBayesClassifier as NB
from classicML.api.models.bayes.semi_naive_bayes_classifiers import AveragedOneDependentEstimator
from classicML.api.models.bayes.semi_naive_bayes_classifiers import AveragedOneDependentEstimator as AODE
from classicML.api.models.bayes.semi_naive_bayes_classifiers import SuperParentOneDependentEstimator
from classicML.api.models.bayes.semi_naive_bayes_classifiers import SuperParentOneDependentEstimator as SPODE

from classicML.api.models.tree.decision_tree_classifier import DecisionStumpClassifier
from classicML.api.models.tree.decision_tree_classifier import TwoLevelDecisionTreeClassifier
from classicML.api.models.ensemble.bagging import BaggingClassifier
from classicML.api.models.ensemble.boosting import AdaBoostClassifier

from classicML.api.models.linear_model.linear_discriminant_analysis import LinearDiscriminantAnalysis
from classicML.api.models.linear_model.linear_discriminant_analysis import LinearDiscriminantAnalysis as LDA
from classicML.api.models.linear_model.logistic_regression import LogisticRegression

from classicML.api.models.neural_network.back_propagation_neural_network import BackPropagationNeuralNetwork
from classicML.api.models.neural_network.back_propagation_neural_network import BackPropagationNeuralNetwork as BPNN
from classicML.api.models.neural_network.radial_basis_function_network import RadialBasisFunctionNetwork
from classicML.api.models.neural_network.radial_basis_function_network import RadialBasisFunctionNetwork as RBF

from classicML.api.models.support_vector_machine.support_vector_classifier import SupportVectorClassifier
from classicML.api.models.support_vector_machine.support_vector_classifier import SupportVectorClassifier as SVC

from classicML.api.models.tree.decision_tree_classifier import DecisionTreeClassifier
